@@ -1,4 +1,4 @@
-from os import environ, getenv
+from os import getenv
 
 
 def get_bool(key: str, default: bool) -> bool:
@@ -7,8 +7,9 @@ def get_bool(key: str, default: bool) -> bool:
     return getenv(key, str(default)).lower() in ("true", "t", "yes", "y", "1")
 
 
-TOKEN: str = environ["TOKEN"]  # bot token
+TOKEN: str | None = getenv("TOKEN")  # bot token
 LOG_LEVEL: str = getenv("LOG_LEVEL", "INFO")
+PYCORD_LOG_LEVEL: str = getenv("PYCORD_LOG_LEVEL", "ERROR")
 
 # database configuration
 DB_DRIVER: str = getenv("DB_DRIVER", "mysql+aiomysql")
@@ -22,15 +23,15 @@ POOL_SIZE: int = int(getenv("POOL_SIZE", 20))
 MAX_OVERFLOW: int = int(getenv("MAX_OVERFLOW", 20))
 SQL_SHOW_STATEMENTS: bool = get_bool("SQL_SHOW_STATEMENTS", False)
 
-SENTRY_DSN: str = getenv("SENTRY_DSN")  # sentry data source name
-GITHUB_TOKEN: str = getenv("GITHUB_TOKEN")  # github personal access token
+SENTRY_DSN: str | None = getenv("SENTRY_DSN")  # sentry data source name
+GITHUB_TOKEN: str | None = getenv("GITHUB_TOKEN")  # github personal access token
 
 OWNER_ID: int = int(getenv("OWNER_ID", 0))
 
 DISABLED_COGS: set[str] = set(map(str.lower, getenv("DISABLED_COGS", "").split(",")))
 
 # redis configuration
-REDIS_HOST: str = environ["REDIS_HOST"]
+REDIS_HOST: str = getenv("REDIS_HOST", "localhost")
 REDIS_PORT: int = int(getenv("REDIS_PORT", "6379"))
 REDIS_DB: int = int(getenv("REDIS_DB", "0"))
 
